==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/Qt/Widgets/pqHighlightablePushButton.cxx <==
/*=========================================================================

   Program: ParaView
   Module:  pqHighlightablePushButton.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#include "pqHighlightablePushButton.h"

#include <QPalette>
#include <QColor>

class pqHighlightablePushButton::pqInternals
{
public:
  QPalette ResetPalette;
};

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(QWidget *parentA)
  : Superclass(parentA),
  Internals(new pqHighlightablePushButton::pqInternals())
{
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(
  const QString &textA, QWidget *parentA)
  : Superclass(textA, parentA),
  Internals(new pqHighlightablePushButton::pqInternals())
{
  this->Internals->ResetPalette = this->palette();
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(
  const QIcon &iconA, const QString &textA, QWidget *parentA)
  : Superclass(iconA, textA, parentA),
  Internals(new pqHighlightablePushButton::pqInternals())
{
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::~pqHighlightablePushButton()
{
}

//-----------------------------------------------------------------------------
void pqHighlightablePushButton::highlight(bool clearHighlight)
{
  QPalette buttonPalette = this->Internals->ResetPalette;
  if (clearHighlight == false)
    {
    buttonPalette.setColor(QPalette::Active, QPalette::Button, QColor(161, 213, 135));
    buttonPalette.setColor(QPalette::Inactive, QPalette::Button, QColor(161, 213, 135));
    }
  this->setPalette(buttonPalette);
}

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/Qt/Widgets/pqHighlightablePushButton.cxx <==
/*=========================================================================

   Program: ParaView
   Module:  pqHighlightablePushButton.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#include "pqHighlightablePushButton.h"

#include <QColor>
#include <QPalette>

class pqHighlightablePushButton::pqInternals
{
public:
  QPalette ResetPalette;
};

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(QWidget* parentA)
  : Superclass(parentA)
  , Internals(new pqHighlightablePushButton::pqInternals())
{
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(const QString& textA, QWidget* parentA)
  : Superclass(textA, parentA)
  , Internals(new pqHighlightablePushButton::pqInternals())
{
  this->Internals->ResetPalette = this->palette();
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::pqHighlightablePushButton(
  const QIcon& iconA, const QString& textA, QWidget* parentA)
  : Superclass(iconA, textA, parentA)
  , Internals(new pqHighlightablePushButton::pqInternals())
{
}

//-----------------------------------------------------------------------------
pqHighlightablePushButton::~pqHighlightablePushButton()
{
}

//-----------------------------------------------------------------------------
void pqHighlightablePushButton::highlight(bool clearHighlight)
{
  QPalette buttonPalette = this->Internals->ResetPalette;
  if (clearHighlight == false)
  {
    buttonPalette.setColor(QPalette::Active, QPalette::Button, QColor(161, 213, 135));
    buttonPalette.setColor(QPalette::Inactive, QPalette::Button, QColor(161, 213, 135));
  }
  this->setPalette(buttonPalette);
}
